#
# spec file for package python-muranoclient
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-muranoclient
Version:        1.1.1
Release:        2.30
Summary:        Python API and CLI for OpenStack Murano
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://launchpad.net/%{name}
Source0:        https://files.pythonhosted.org/packages/source/p/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-PrettyTable >= 0.7.2
BuildRequires:  python-devel
BuildRequires:  python-fixtures
BuildRequires:  python-glanceclient >= 2.8.0
BuildRequires:  python-keystoneclient >= 3.8.0
BuildRequires:  python-mock
BuildRequires:  python-murano-pkg-check >= 0.3.0
BuildRequires:  python-osc-lib >= 1.8.0
BuildRequires:  python-oslo.log >= 3.36.0
BuildRequires:  python-oslo.serialization >= 2.18.0
BuildRequires:  python-oslo.utils >= 3.33.0
BuildRequires:  python-pbr >= 2.0.0
BuildRequires:  python-pyOpenSSL >= 17.1.0
BuildRequires:  python-requests-mock
BuildRequires:  python-setuptools
BuildRequires:  python-stestr
BuildRequires:  python-testscenarios
BuildRequires:  python-testtools
BuildRequires:  python-yaql >= 1.1.3
Requires:       python-Babel >= 2.3.4
Requires:       python-PrettyTable >= 0.7.2
Requires:       python-PyYAML >= 3.12
Requires:       python-glanceclient >= 2.8.0
Requires:       python-iso8601 >= 0.1.11
Requires:       python-keystoneclient >= 3.8.0
Requires:       python-murano-pkg-check >= 0.3.0
Requires:       python-osc-lib >= 1.8.0
Requires:       python-oslo.i18n >= 3.15.3
Requires:       python-oslo.log >= 3.36.0
Requires:       python-oslo.serialization >= 2.18.0
Requires:       python-oslo.utils >= 3.33.0
Requires:       python-pbr >= 2.0.0
Requires:       python-pyOpenSSL >= 17.1.0
Requires:       python-requests >= 2.14.2
Requires:       python-six >= 1.10.0
Requires:       python-yaql >= 1.1.3
BuildArch:      noarch

%description
Client library for Murano built on the Murano API. It provides a Python API
(the muranoclient module) and a command-line tool (murano).

%package doc
Summary:        Documentation for OpenStack Magnum API client libary
Group:          Documentation/HTML
BuildRequires:  python-Sphinx
BuildRequires:  python-openstackdocstheme
BuildRequires:  python-reno

%description doc
Client library for Murano built on the Murano API. It provides a Python API
(the muranoclient module) and a command-line tool (murano).
This package contains the documentation.

%prep
%autosetup -n %{name}-%{version}
%py_req_cleanup
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
%py2_build

# Build HTML docs and man page
PBR_VERSION=%version sphinx-build -b html doc/source doc/build/html

%install
%py2_install

%check
stestr run

%files
%doc README.rst
%license LICENSE
%{python2_sitelib}/muranoclient
%{python2_sitelib}/*.egg-info
%{_bindir}/murano

%files doc
%doc doc/build/html
%license LICENSE

%changelog
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 1.1.1
  - Switch to stestr
  - fix tox python3 overrides
  - Add os-testr to test-requirements.txt
  - Update reno for stable/queens
  - Add release note link in README
  - Fix incompatible requirement
  - Trivial: Update pypi url to new url
  - Ignore default values for deprecated security parameters
  - Imported Translations from Zanata
  - Follow the new PTI for document build
  - Trivial: update url to new url
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Tue Jan 30 2018 cloud-devel@suse.de
- update to version 1.0.1
  - update env template output
  - Skip two test due to apps.openstack.org is retired
  - Imported Translations from Zanata
  - Update links in README
  - Update reno for stable/pike
  - Add bundle import to openstack CLI
  - Remove setting of version/release from releasenotes
  - Update the documentation link for doc migration
  - Add package show to openstack CLI
  - Add package update to openstack CLI
  - Avoid tox_install.sh for constraints support
  - Fix to use "." to source script files
  - Updated from global requirements
  - Add package download to openstack CLI
  - Use generic user for both zuul v2 and v3
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 0.14.0
  - Make method import_versioned_module work
  - Correct the unit test name
  - Remove long-ago deprecated show_categories
  - Imported Translations from Zanata
  - Add package import to openstack CLI
  - Update reno for stable/ocata
  - import content from cli-reference in openstack-manuals
  - Optimize the link address
  - Update the documentation link for doc migration
  - Replace six.iteritems() with .items()
  - Using the latest openstackdocstheme settings
  - move existing content into the new standard structure
  - Modify Default Domain
  - delete bash_completion in subcommand
  - Remove log translations
  - Update test requirement
  - Turn on warning-is-error in sphinx build
  - Remove support for py34
  - switch to openstackdocstheme
  - Replaces uuid.uuid4 with uuidutils.generate_uuid()
  - Allows fetching of deployments from all environments.
  - Updated from global requirements
* Sat Mar 25 2017 dmueller@suse.com
- update to 0.12.0:
  * Add debug to tox enviroment
  * Remove white space between print ()
  * Fixes filtering applications by name with glare
  * Remove the data assert to pass the gate
  * Add package delete to openstack CLI
  * Using sys.exit(main()) instead of main()
  * Return error code when a error occurred during package-import
  * Fix Murano client to use V3 and MultiDomain Authentication
  * Use assertGreater() and assertLess()
  * Support i18n for LOG.warning
  * Show team and repo badges on README
  * Support for environment list filtering by project id
  * Delete python bytecode file
  * Fix typos in cover.sh
  * Fix removes date_time items from dictionaries
  * Fix removes date_time items from dictionaries
  * Updated from global requirements
  * Add functional test for environment-model-show
  * Fix OpenStack Licensing
  * OSC plugin should be using region/interface
  * Enable release notes translation
  * Add support for environment edit API
  * Fixing environment creation from template
  * Unskip the test due to bugfix
  * Skip some tests when using glare in a right way
  * Mark .testr.conf as non-executable
  * Make some OSC tests more clean
  * Updated from global requirements
  * TrivialFix: Fix typo in the bash shell file
  * Add package list to openstack CLI
  * TrivialFix: Using assertTrue() instead of assertEqual(True)
  * Remove unnecessary setUp
  * Make --limit argument in package-list command robust
  * Add opportunity to import package from directory
* Tue Nov 15 2016 dmueller@suse.com
- update to 0.11.1:
  * Populate tenant information in client
* Mon Sep  5 2016 tbechtold@suse.com
  update to version 0.11.0
  * Increase yaql quotas
  * Replace functions 'Dict.get' and 'del' with 'Dict.pop'
  * Add package create to openstack CLI
  * Decode PrettyTable output before printing for Python3
  * Add script for unit test coverage job
  * Use upper constraints for all jobs in tox.ini
  * [docs] Update Readme with correct Doc URL
  * Updated from global requirements
  * Sync tools/tox_install.sh
  * Trivial: clean up oslo-incubator related stuff
* Thu Aug 25 2016 tbechtold@suse.com
- Initial packaging (version 0.10.0)
